fn is_empty(
world: &dyn LevelReader,
pos: BlockPos,
config: &PortalFrameConfig,
) -> boolExpand description
Matches vanilla’s PortalShape.isEmpty: any air variant, any block in the fire tag,
or the portal block itself.
fn is_empty(
world: &dyn LevelReader,
pos: BlockPos,
config: &PortalFrameConfig,
) -> boolMatches vanilla’s PortalShape.isEmpty: any air variant, any block in the fire tag,
or the portal block itself.